@@ -4,7 +4,7 @@ use base qw( CatalystX::CRUD::Controller );
 use Carp;
 use Class::C3;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 =head1 NAME
 
@@ -77,7 +77,7 @@ sub all_form_errors {
     for my $f ( $form->fields ) {
         push( @err, $f->name . ': ' . $f->error ) if $f->error;
     }
-    return join( "\n", @err );
+    return join( "\n", grep {defined} @err );
 }
 
 =head2 form_to_object( I<context> )
@@ -115,9 +115,9 @@ sub form_to_object {
 
     # return if there was a problem with any param values
     unless ( $form->validate() ) {
-        $c->stash->{error} = $form->error;    # NOT throw_error()
-        $c->log->debug(
-            "RHTMLO: form error:\n" . $self->all_form_errors($form) )
+        my $err = $self->all_form_errors($form);
+        $c->stash( error => $err );    # NOT throw_error()
+        $c->log->debug("RHTMLO: form error:\n$err\n")
             if $c->debug;
         $c->stash->{template} ||= $self->default_template;    # MUST specify
         return 0;
@@ -148,6 +148,7 @@ sub do_search {
     # if we have no input, just return for initial search
     if ( !@arg && !$c->req->param && $c->action->name eq 'search' ) {
         $c->log->debug("no input to search. return") if $c->debug;
+
         # must clear explicitly since this is a new search
         # and form may have been initialized elsewhere
         $c->stash->{form}->clear;
